package org.apache.maven.repository.indexing.query;

/*
 * Copyright 2005-2006 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.apache.lucene.index.Term;
import org.apache.maven.repository.indexing.RepositoryIndex;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/**
 * Query object that handles range queries for dates.
 *
 * @author Maria Odea Ching
 */
public class RangeQuery
    implements Query
{
    private List queries = new ArrayList();

    private boolean inclusive;

    public RangeQuery( boolean inclusive )
    {
        this.inclusive = inclusive;
    }

    public void addQuery( Query qry )
    {
        queries.add( qry );
    }

    public List getQueries()
    {
        return queries;
    }

    public boolean isInclusive()
    {
        return inclusive;
    }

    public org.apache.lucene.search.Query createLuceneQuery( RepositoryIndex index )
    {
        List queries = this.queries;
        Iterator iter = queries.iterator();
        Term begin = null;
        Term end = null;
        if ( queries.size() == 2 )
        {
            SinglePhraseQuery qry = (SinglePhraseQuery) iter.next();
            begin = new Term( qry.getField(), qry.getValue() );
            qry = (SinglePhraseQuery) iter.next();
            end = new Term( qry.getField(), qry.getValue() );
        }
        return new org.apache.lucene.search.RangeQuery( begin, end, this.inclusive );
    }
}
